middleware

package
v0.12.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 15, 2025 License: GPL-3.0 Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func BasicAuth

func BasicAuth(creds map[string]string) httpx.Handler

creds input param accept a map in format username=password where password string must be encoded by bcrypt

func Logger added in v0.11.0

func Logger(logHeaders bool) httpx.Handler

func RealIP

func RealIP(header string) httpx.Handler

func Recover

func Recover(req *http.Request, resp *httpx.Response) error

func TraceID added in v0.11.0

func TraceID(req *http.Request, resp *httpx.Response) error

Types

This section is empty.

Jump to